/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.properties.faults;

import org.apache.ws.resource.faults.BaseFaultException;
import org.apache.ws.resource.properties.v1_2.ResourceProperties1_2Constants;
import org.apache.ws.resource.properties.query.QueryExpression;
import org.apache.ws.resource.properties.query.xpath.XPathExpression;
import org.apache.ws.resource.i18n.MessagesImpl;
import org.apache.ws.resource.i18n.Keys;
import org.apache.ws.util.i18n.Messages;

import javax.xml.namespace.QName;

/**
 * LOG-DONE
 * WS-ResourceProperties InvalidQueryExpression fault type implemented as a Java exception.
 *
 * @author Ian P. Springer
 */
public class InvalidQueryExpressionFaultException
   extends BaseFaultException
{
   public static final Messages MSG = MessagesImpl.getInstance();
   /**
    * DOCUMENT_ME
    */
   private static final QName NAME =
      new QName( ResourceProperties1_2Constants.NSURI_WSRP_SCHEMA, "InvalidQueryExpressionFault",
                 ResourceProperties1_2Constants.NSPREFIX_WSRP_SCHEMA );

   /**
    * Constructs a new BaseFaultException with the specified SOAP message and actor.
    *
    * @param queryExpr the invalid expression
    */
   public InvalidQueryExpressionFaultException( QueryExpression queryExpr )
   {
      super( NAME );
      setDescription( new String[]
                      {
                         MSG.getMessage( Keys.INVALID_EXPRESSION,queryExpr)
                      } );
   }

   /**
    * Constructs a new BaseFaultException with the specified SOAP message and actor.
    *
    * @param xpathExpr the invalid expression
    */
   public InvalidQueryExpressionFaultException( XPathExpression xpathExpr )
   {
      super( NAME );
      setDescription( new String[]
                      {
                         MSG.getMessage( Keys.INVALID_EXPRESSION,xpathExpr)
                      } );
   }
}