/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.properties.faults;

import org.apache.ws.resource.ResourceUnknownException;
import org.apache.ws.resource.i18n.MessagesImpl;
import org.apache.ws.resource.i18n.Keys;
import org.apache.ws.resource.faults.BaseFaultException;
import org.apache.ws.resource.properties.v1_2.ResourceProperties1_2Constants;
import org.apache.ws.util.i18n.Messages;

import javax.xml.namespace.QName;

/**
 * LOG-DONE
 * Indicates that the resource identified in the message is not known to the Web service.
 *
 * @author Ian P. Springer
 */
public class ResourceUnknownFaultException
   extends BaseFaultException
{
   public static final Messages MSG = MessagesImpl.getInstance();
   /**
    * DOCUMENT_ME
    */
   private static final QName NAME =
      new QName( ResourceProperties1_2Constants.NSURI_WSRP_SCHEMA, "ResourceUnknownFault",
                 ResourceProperties1_2Constants.NSPREFIX_WSRP_SCHEMA );
   private Object             m_resourceId;
   private String             m_serviceName;

   /**
    * Constructs a new ResourceUnknownFaultException, specifying the resource id and service name of the unknown
    * resource.
    *
    * @param resourceId
    * @param serviceName
    */
   public ResourceUnknownFaultException( Object resourceId,
                                         String serviceName )
   {
      super( NAME );
      setDescription( new String[]
                      {
                          MSG.getMessage( Keys.RESOURCEID_NOT_FOUND_FOR_SERVICE, resourceId, serviceName)
                      } );
      m_resourceId     = resourceId;
      m_serviceName    = serviceName;
   }

   /**
    * @param rue
    */
   public ResourceUnknownFaultException( ResourceUnknownException rue )
   {
      this( rue.getResourceId(  ),
            rue.getServiceName(  ) );
   }

   /**
    * DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public Object getResourceId(  )
   {
      return m_resourceId;
   }

   /**
    * DOCUMENT_ME
    *
    * @return DOCUMENT_ME
    */
   public String getServiceName(  )
   {
      return m_serviceName;
   }
}