/*=============================================================================*
 *  Copyright 2004 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *=============================================================================*/
package org.apache.ws.resource.properties.faults;

import org.apache.ws.resource.faults.BaseFaultException;
import org.apache.ws.resource.i18n.Keys;
import org.apache.ws.resource.properties.v1_2.ResourceProperties1_2Constants;

import javax.xml.namespace.QName;
import java.net.URI;

/**
 * LOG-DONE WS-ResourceProperties UnknownQueryExpressionDialect fault type implemented as a Java exception.
 *
 * @author Ian P. Springer
 */
public class UnknownQueryExpressionDialectFaultException
        extends BaseFaultException
{
    /**
     * DOCUMENT_ME
     */
    private static final QName NAME =
            new QName( ResourceProperties1_2Constants.NSURI_WSRP_SCHEMA, "UnknownQueryExpressionDialectFault",
                    ResourceProperties1_2Constants.NSPREFIX_WSRP_SCHEMA );
    private URI m_dialect;

    /**
     * Constructs a new BaseFaultException with the specified SOAP message and actor.
     *
     * @param dialect the URI of the unsupported dialect
     */
    public UnknownQueryExpressionDialectFaultException( URI dialect )
    {
        super( NAME );
        m_dialect = dialect;
        setDescription( new String[]
        {
            MSG.getMessage( Keys.DIALECT, dialect )
        } );
    }

    /**
     * Returns the URI of the unsupported dialect.
     *
     * @return the URI of the unsupported dialect
     */
    public URI getDialect()
    {
        return m_dialect;
    }
}